*Data Dofile 5 Analysis_HIVafter40_Twin_Epidemics_Public
*Created by Andrea Tilstra, edited by Brian Houle and Jane Menken
*Last edited: July 10, 2022

/*Notes:
  This script uses the public version of the data for analyses for the Twin
  Epidemics paper. The data are into person-year format, and all 
  personal-identifying information has been removed. 
*/

/* Replication of tests in lines 326-353 depends on STATA version. Select the newer 
  versions if using STATA 16 or later
*/

** if necessary, adjust the path to the dataset
use "HIVafter40_Twin_Epidemics_HIV_Hyp.dta", clear	


***********************************
*Table 1: Descriptive Statistics*
***********************************

svyset [pweight=wt_new]

* Get the overall sample size aged 40 plus
count if m==M & AgeYear>=40 & Outcome==1

* Number who died
tab dead if m==M & AgeYear>=40 & Outcome==1
tab EndYear if m==M & AgeYear>=40 & Outcome==1

*Row 5: % dead
*Men:
svy: tab EndYear if m==M & male==1 & AgeYear>=40 & Outcome==1
*Women:
svy: tab EndYear if m==M & male==0 & AgeYear>=40 & Outcome==1


*Rows 6-38: Age Group-HH Wealth Tercile
*Men
foreach var of varlist agecat vl_simple_400 south_african mar3 edu working qses3 {
	svy: tab `var' if m==M & male==1 & AgeYear>=40 & Outcome==1

}
*Women
foreach var of varlist agecat vl_simple_400 south_african mar3 edu working qses3 {
	svy: tab `var' if m==M & male==0 & AgeYear>=40 & Outcome==1

}


*Rows 40-47: SBP
*Men
svy: mean systolic2 if male==1 & m==M & AgeYear>=40 & Outcome==1
svy: mean systolic2 if vl_simple_400==0 & male==1 & m==M & AgeYear>=40 & Outcome==1
svy: mean systolic2 if vl_simple_400==1 & male==1 & m==M & AgeYear>=40 & Outcome==1
svy: mean systolic2 if vl_simple_400==2 & male==1 & m==M & AgeYear>=40 & Outcome==1
count if systolic2==. & male==1 & m==M & AgeYear>=40 & Outcome==1
count if systolic2==. & vl_simple_400==. & male==1 & m==M & AgeYear>=40 & Outcome==1

*Women
svy: mean systolic2 if male==0 & m==M & AgeYear>=40 & Outcome==1
svy: mean systolic2 if vl_simple_400==0 & male==0 & m==M & AgeYear>=40 & Outcome==1
svy: mean systolic2 if vl_simple_400==1 & male==0 & m==M & AgeYear>=40 & Outcome==1
svy: mean systolic2 if vl_simple_400==2 & male==0 & m==M & AgeYear>=40 & Outcome==1
count if systolic2==. & male==0 & m==M & AgeYear>=40 & Outcome==1
count if systolic2==. & vl_simple_400==. & male==0 & m==M & AgeYear>=40 & Outcome==1


*Rows 49-64: HIV + Hypertension --

*Men
svy: tab hiv_positive agecat if male==1 & m==M, col row
svy: tab hyp_simple agecat if male==1 & m==M, col row
*svy: tab hiv_positive hyp_simple if male==1 & m==M & agecat==1
svy: tab hiv_positive hyp_simple if male==1 & m==M & agecat==2
svy: tab hiv_positive hyp_simple if male==1 & m==M & agecat==3
svy: tab hiv_positive hyp_simple if male==1 & m==M & agecat==4

*Women
svy: tab hiv_positive agecat if male==0 & m==M, col row
svy: tab hyp_simple agecat if male==0 & m==M, col row
*svy: tab hiv_positive hyp_simple if male==0 & m==M & agecat==1
svy: tab hiv_positive hyp_simple if male==0 & m==M & agecat==2
svy: tab hiv_positive hyp_simple if male==0 & m==M & agecat==3
svy: tab hiv_positive hyp_simple if male==0 & m==M & agecat==4



******************************************************
*Figure 1: Age-Specific SBP dist, by Sex & HIV Status*
******************************************************

*Men, HIV+
svy: tab sbp_cat2 if male==1 & m==M & Outcome==1 & hiv_positive==1 & agecat==2
svy: tab sbp_cat2 if male==1 & m==M & Outcome==1 & hiv_positive==1 & agecat==3
svy: tab sbp_cat2 if male==1 & m==M & Outcome==1 & hiv_positive==1 & agecat==4

*Men, HIV-
svy: tab sbp_cat2 if male==1 & m==M & Outcome==1 & hiv_positive==0 & agecat==2
svy: tab sbp_cat2 if male==1 & m==M & Outcome==1 & hiv_positive==0 & agecat==3
svy: tab sbp_cat2 if male==1 & m==M & Outcome==1 & hiv_positive==0 & agecat==4

*Women, HIV+
svy: tab sbp_cat2 if male==0 & m==M & Outcome==1 & hiv_positive==1 & agecat==2
svy: tab sbp_cat2 if male==0 & m==M & Outcome==1 & hiv_positive==1 & agecat==3
svy: tab sbp_cat2 if male==0 & m==M & Outcome==1 & hiv_positive==1 & agecat==4

*Women, HIV-
svy: tab sbp_cat2 if male==0 & m==M & Outcome==1 & hiv_positive==0 & agecat==2
svy: tab sbp_cat2 if male==0 & m==M & Outcome==1 & hiv_positive==0 & agecat==3
svy: tab sbp_cat2 if male==0 & m==M & Outcome==1 & hiv_positive==0 & agecat==4


*Both, HIV+
svy: tab sbp_cat2 if m==M & Outcome==1 & hiv_positive==1 & agecat==2
svy: tab sbp_cat2 if m==M & Outcome==1 & hiv_positive==1 & agecat==3
svy: tab sbp_cat2 if m==M & Outcome==1 & hiv_positive==1 & agecat==4

*Both, HIV-
svy: tab sbp_cat2 if m==M & Outcome==1 & hiv_positive==0 & agecat==2
svy: tab sbp_cat2 if m==M & Outcome==1 & hiv_positive==0 & agecat==3
svy: tab sbp_cat2 if m==M & Outcome==1 & hiv_positive==0 & agecat==4

*All Men
svy: tab sbp_cat2 if male==1 & m==M & Outcome==1 & agecat==2
svy: tab sbp_cat2 if male==1 & m==M & Outcome==1 & agecat==3
svy: tab sbp_cat2 if male==1 & m==M & Outcome==1 & agecat==4

*All Women
svy: tab sbp_cat2 if male==0 & m==M & Outcome==1 & agecat==2
svy: tab sbp_cat2 if male==0 & m==M & Outcome==1 & agecat==3
svy: tab sbp_cat2 if male==0 & m==M & Outcome==1 & agecat==4

* All
recode sbp_cat2 (1 2 = 0) (3 4 = 1), gen(sbp_collapsed)
svy: tab sbp_collapsed if m==M & Outcome==1 & agecat==2
svy: tab sbp_collapsed if m==M & Outcome==1 & agecat==3
svy: tab sbp_collapsed if m==M & Outcome==1 & agecat==4

svy: tab sbp_collapsed if male == 1 & m==M & Outcome==1 & agecat==2
svy: tab sbp_collapsed if male == 1 & m==M & Outcome==1 & agecat==3
svy: tab sbp_collapsed if male == 1 & m==M & Outcome==1 & agecat==4

svy: tab sbp_collapsed if male == 0 & m==M & Outcome==1 & agecat==2
svy: tab sbp_collapsed if male == 0 & m==M & Outcome==1 & agecat==3
svy: tab sbp_collapsed if male == 0 & m==M & Outcome==1 & agecat==4



**************************
*Table 2: Final Models*
**************************
*Men

* Test without weights
logit EndYear AgeYear i.vl_simple_400 i.mar3 i.edu histbpmed c.systolic2 if male==1 & AgeYear>=40 , or
	estimates store m1
logit EndYear AgeYear i.vl_simple_400 i.mar3 i.edu histbpmed c.systolic2##c.systolic2 if male==1 & AgeYear>=40 , or
	estimates store m2

	lrtest m1 m2

* Test with weights
logit EndYear AgeYear i.vl_simple_400 i.mar3 i.edu histbpmed c.systolic2##c.systolic2 if male==1 & AgeYear>=40 [pweight=wt_new], or
	estimates store menf
	test c.systolic2 c.systolic2#c.systolic2
	margins i.vl_simple_400, coeflegend post
		test _b[0bn.vl_simple_400] = _b[2.vl_simple_400]
	estimates restore menf
		margins , dydx(vl_simple_400)
	estimates restore menf
	margins , at(systolic2 = (110(10)170)) coeflegend post
		lincom _b[1bn._at] - _b[4._at]
		lincom _b[7._at] - _b[4._at]

	logit EndYear AgeYear i.vl_simple_400 i.mar3 i.edu histbpmed c.systolic2##c.systolic2 i.vl_simple_400#c.systolic2 if male==1 & AgeYear>=40 [pweight=wt_new], or
	logit EndYear AgeYear i.mar3 i.edu histbpmed i.vl_simple_400##(c.systolic2##c.systolic2) i.vl_simple_400#c.systolic2 if male==1 & AgeYear>=40 [pweight=wt_new], or

*Women

* Test without weights
logit EndYear AgeYear i.vl_simple_400 i.mar3 i.edu histbpmed c.systolic2 if male==0 & AgeYear>=40, or
	estimates store m1

logit EndYear AgeYear i.vl_simple_400 i.mar3 i.edu histbpmed c.systolic2##c.systolic2 if male==0 & AgeYear>=40, or
	estimates store m2

	lrtest m1 m2

* Test with weights
logit EndYear AgeYear i.vl_simple_400 i.mar3 i.edu histbpmed c.systolic2##c.systolic2 if male==0 & AgeYear>=40 [pweight=wt_new], or
	estimates store womenf
	test c.systolic2 c.systolic2#c.systolic2
	margins i.vl_simple_400, coeflegend post
		test _b[0bn.vl_simple_400] = _b[2.vl_simple_400]
	estimates restore womenf
		margins , dydx(vl_simple_400)
	estimates restore womenf
	margins , at(systolic2 = (110(10)170)) coeflegend post
		lincom _b[1bn._at] - _b[4._at]
		lincom _b[7._at] - _b[4._at]

	logit EndYear AgeYear i.vl_simple_400 i.mar3 i.edu histbpmed c.systolic2##c.systolic2 i.vl_simple_400#c.systolic2 if male==0 & AgeYear>=40 [pweight=wt_new], or
	logit EndYear AgeYear i.mar3 i.edu histbpmed i.vl_simple_400##(c.systolic2##c.systolic2) i.vl_simple_400#c.systolic2 if male==0 & AgeYear>=40 [pweight=wt_new], or

********************************
*Other values for Manuscript*
********************************

*(1) SBP % by Sex & Age Group

svy: tab sbp_cat2 if male==1 & m==M & Outcome==1 & agecat==2
svy: tab sbp_cat2 if male==1 & m==M & Outcome==1 & agecat==3
svy: tab sbp_cat2 if male==1 & m==M & Outcome==1 & agecat==4


svy: tab sbp_cat2 if male==0 & m==M & Outcome==1 & agecat==2
svy: tab sbp_cat2 if male==0 & m==M & Outcome==1 & agecat==3
svy: tab sbp_cat2 if male==0 & m==M & Outcome==1 & agecat==4



******************
*Supplementary T1*
******************
* A: no covariates
* B: all covariates
* C: alt VL threshold


*Men, A
logit EndYear AgeYear i.vl_simple_400 systolic2 histbpmed c.systolic2#c.systolic2 if male==1 & AgeYear>=40 [pweight=wt_new], or

*Men, B
logit EndYear AgeYear i.vl_simple_400 systolic2 histbpmed c.systolic2#c.systolic2 south_african i.mar3 i.edu working i.qses3 if male==1 & AgeYear>=40 [pweight=wt_new], or

*Men, C
logit EndYear AgeYear i.vl_simple_2013 i.mar3 i.edu systolic2 histbpmed c.systolic2#c.systolic2 if male==1 & AgeYear>=40 [pweight=wt_new], or


*Women, A
logit EndYear AgeYear i.vl_simple_400 systolic2 histbpmed c.systolic2#c.systolic2 if male==0 & AgeYear>=40 [pweight=wt_new], or

*Women, B
logit EndYear AgeYear i.vl_simple_400 systolic2 histbpmed c.systolic2#c.systolic2 south_african i.mar3 i.edu working i.qses3 if male==0 & AgeYear>=40 [pweight=wt_new], or

*Women, C
logit EndYear AgeYear i.vl_simple_2013 i.mar3 i.edu systolic2 histbpmed c.systolic2#c.systolic2 if male==0 & AgeYear>=40 [pweight=wt_new], or

count if m==M & AgeYear>=40 & male==1 & vl_simple_400!=. & systolic2!=. & histbpmed!=. 
count if m==M & AgeYear>=40 & male==1 & vl_simple_400!=. & systolic2!=. & histbpmed!=. & south_african!=. & mar3!=. & edu!=. & working!=. & qses3!=. 
count if m==M & AgeYear>=40 & male==1 & vl_simple_2013!=. & systolic2!=. & histbpmed!=. & mar3!=. & edu!=. 

count if m==M & AgeYear>=40 & male==0 & vl_simple_400!=. & systolic2!=. & histbpmed!=. 
count if m==M & AgeYear>=40 & male==0 & vl_simple_400!=. & systolic2!=. & histbpmed!=. & south_african!=. & mar3!=. & edu!=. & working!=. & qses3!=. 
count if m==M & AgeYear>=40 & male==0 & vl_simple_2013!=. & systolic2!=. & histbpmed!=. & mar3!=. & edu!=.


******************
*Supplementary T2*
******************

*Final model but w/ DBP 


*Men
* Without weights
logit EndYear AgeYear i.vl_simple_400 i.mar3 i.edu histbpmed c.diastolic2 if male==1 & AgeYear>=40, or
	estimates store m1
logit EndYear AgeYear i.vl_simple_400 i.mar3 i.edu histbpmed c.diastolic2##c.diastolic2 if male==1 & AgeYear>=40, or
	estimates store m2

	lrtest m1 m2

* With weights
logit EndYear AgeYear i.vl_simple_400 i.mar3 i.edu histbpmed c.diastolic2##c.diastolic2 if male==1 & AgeYear>=40 [pweight=wt_new], or
	test c.diastolic2 c.diastolic2#c.diastolic2

*Women

* Without weights
logit EndYear AgeYear i.vl_simple_400 i.mar3 i.edu histbpmed c.diastolic2 if male==0 & AgeYear>=40, or
	estimates store m1
logit EndYear AgeYear i.vl_simple_400 i.mar3 i.edu histbpmed c.diastolic2##c.diastolic2 if male==0 & AgeYear>=40, or
	estimates store m2

	lrtest m1 m2

* With weights
logit EndYear AgeYear i.vl_simple_400 i.mar3 i.edu diastolic2 histbpmed c.diastolic2#c.diastolic2 if male==0 & AgeYear>=40 [pweight=wt_new], or
		test c.diastolic2 c.diastolic2#c.diastolic2

count if m==M & AgeYear>=40 & male==1 & vl_simple_400!=. & diastolic2!=. & histbpmed!=. & mar3!=. & edu!=. 
count if m==M & AgeYear>=40 & male==0 & vl_simple_400!=. & diastolic2!=. & histbpmed!=. & mar3!=. & edu!=. 




***************************
*R&R - BMC Public Health*
* Added: January 17
***************************

*Table 1: Are the diffs by sex significant?

*Row 5: % dead
svy: tab EndYear male if m==M & AgeYear>=40 & Outcome==1
*Yes, sig diff @ p<0.001

*Rows 6-38: Age Group-HH Wealth Tercile
foreach var of varlist agecat vl_simple_400 south_african mar3 edu working qses3 {
	svy: tab `var' male if m==M & AgeYear>=40 & Outcome==1

}
*agecat: not sig (p = 0.068)
*vl_simple_400: sig (p = 0.003)
*south african: sig (p = 0.007)
*mar3: sig (p<0.001)
*edu: sig (p<0.001)
*working: sig (p<0.001)
*qses3: not sig (p = 0.4028)



*Rows 40-47: SBP
svy: mean systolic2 if m==M & AgeYear>=40 & Outcome==1, over(male) coeflegend
* For newer versions of Stata run the test below:
*test _b[c.systolic2@0bn.male] = _b[c.systolic2@1.male]
* For older versions of Stata run the test below instead: 
/* test _b[female] = _b[male] */
*No, not sig (p = 0.7887)

svy: mean systolic2 if vl_simple_400==0 & m==M & AgeYear>=40 & Outcome==1, over(male) coeflegend
* For newer versions of Stata run the test below:
*test _b[c.systolic2@0bn.male] = _b[c.systolic2@1.male]
* For older versions of Stata run the test below instead: 
/* test _b[female] = _b[male] */
*No, not sig (p = 0.9312)

svy: mean systolic2 if vl_simple_400==1 & m==M & AgeYear>=40 & Outcome==1, over(male) coeflegend
* For newer versions of Stata run the test below:
*test _b[c.systolic2@0bn.male] = _b[c.systolic2@1.male]
* For older versions of Stata run the test below instead: 
/* test _b[female] = _b[male] */
*No, not sig (p = 0.7804)

svy: mean systolic2 if vl_simple_400==2 & m==M & AgeYear>=40 & Outcome==1, over(male) coeflegend
* For newer versions of Stata run the test below:
*test _b[c.systolic2@0bn.male] = _b[c.systolic2@1.male]
* For older versions of Stata run the test below instead: 
/* test _b[female] = _b[male] */
*No, not sig (p = 0.6814)



*Table 1: Overall distributions
*Row 5: % dead
svy: tab EndYear if m==M & AgeYear>=40 & Outcome==1


*Rows 6-38: Age Group-HH Wealth Tercile
foreach var of varlist agecat vl_simple_400 south_african mar3 edu working qses3 {
	svy: tab `var' if m==M & AgeYear>=40 & Outcome==1
}

*Rows 40-47: SBP
svy: mean systolic2 if m==M & AgeYear>=40 & Outcome==1
svy: mean systolic2 if vl_simple_400==0 & m==M & AgeYear>=40 & Outcome==1
svy: mean systolic2 if vl_simple_400==1 & m==M & AgeYear>=40 & Outcome==1
svy: mean systolic2 if vl_simple_400==2 & m==M & AgeYear>=40 & Outcome==1
count if systolic2==. & m==M & AgeYear>=40 & Outcome==1
count if systolic2==. & vl_simple_400==. & m==M & AgeYear>=40 & Outcome==1




*Is SBP>140 statistically different by age group or HIV status?

*by age for men
svy: tab sbp_cat2 agecat if male==1 & m==M & Outcome==1 & inlist(agecat,2,3,4)
*Yes: it's stat diff by age group for men

*by age for women 
svy: tab sbp_cat2 agecat if male==0 & m==M & Outcome==1 & inlist(agecat,2,3,4)
*Yes, it's stat diff by age group for women


*by HIVstatus for men
svy: tab sbp_cat2 vl_simple_400 if male==1 & m==M & Outcome==1 & inlist(agecat,2,3,4)
*Yes, it's stat diff

*by HIVstatus for women
svy: tab sbp_cat2 vl_simple_400 if male==0 & m==M & Outcome==1 & inlist(agecat,2,3,4)
*Yes, it's stat diff




*Mortality rate 
preserve
collapse (count) pyear = _t0 (sum) deaths = EndYear [pweight=wt_new], by(male)
poisson deaths male, exp(pyear) irr
predict rate, ir
replace rate = rate * 100000

*95% CI:
*men:
di .00987527 + (1.96* .033485 * .0001918)
di .00987527 - (1.96* .033485 * .0001918)

*women:
di .00937283 + (1.96 * .0001918)
di .00937283 - (1.96 * .0001918)


restore

